@@ -52,6 +52,7 @@ class PBXResourcesBuildPhase(PBXBuildPhase):
 @deserialize.key("shell_script", "shellScript")
 @deserialize.key("show_env_vars_in_log", "showEnvVarsInLog")
 @deserialize.key("always_out_of_date", "alwaysOutOfDate")
+@deserialize.key("dependency_file", "dependencyFile")
 @deserialize.parser("showEnvVarsInLog", lambda x: {"0": False, "1": True}.get(x, True))
 @deserialize.parser("alwaysOutOfDate", lambda x: {"0": False, "1": True}.get(x, True))
 @deserialize.downcast_identifier(PBXObject, "PBXShellScriptBuildPhase")
@@ -71,6 +72,7 @@ class PBXShellScriptBuildPhase(PBXBuildPhase):
     shell_script: str
     show_env_vars_in_log: Optional[bool]
     always_out_of_date: Optional[bool]
+    dependency_file: Optional[str]
 
 
 @deserialize.key("destination_path", "dstPath")
